@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Version: 1.2
+;; Version: 1.3
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/cape
 ;; Keywords: abbrev, convenience, matching, completion, text
@@ -125,6 +125,7 @@ The buffers are scanned for completion candidates by `cape-line'."
     (markdown-mode ?` ?`)
     (rst-mode "``" "``")
     (log-edit-mode "`" "'")
+    (change-log-mode "`" "'")
     (message-mode "`" "'")
     (rcirc-mode "`" "'"))
   "Wrapper characters for symbols."
@@ -602,10 +603,16 @@ See the user options `cape-dabbrev-min-length' and
   (unless (equal input "")
      (let* ((inhibit-message t)
             (message-log-max nil)
-            (files (ensure-list
-                    (if (functionp cape-dict-file)
-                        (funcall cape-dict-file)
-                      cape-dict-file)))
+            (default-directory
+             (if (and (not (file-remote-p default-directory))
+                      (file-directory-p default-directory))
+                 default-directory
+               user-emacs-directory))
+            (files (mapcar #'expand-file-name
+                           (ensure-list
+                            (if (functionp cape-dict-file)
+                                (funcall cape-dict-file)
+                              cape-dict-file))))
             (words
              (apply #'process-lines-ignore-status
                     "grep"
@@ -1115,6 +1122,13 @@ This function can be used as an advice around an existing Capf."
                 (memq fs faces))))
     (funcall capf)))
 
+;;;###autoload
+(defun cape-wrap-inside-code (capf)
+  "Call CAPF only if inside code, not inside a comment or string.
+This function can be used as an advice around an existing Capf."
+  (let ((s (syntax-ppss)))
+    (and (not (nth 3 s)) (not (nth 4 s)) (funcall capf))))
+
 ;;;###autoload
 (defun cape-wrap-inside-comment (capf)
   "Call CAPF only if inside comment.
@@ -1161,6 +1175,7 @@ This function can be used as an advice around an existing Capf."
 ;;;###autoload (autoload 'cape-capf-buster "cape")
 ;;;###autoload (autoload 'cape-capf-case-fold "cape")
 ;;;###autoload (autoload 'cape-capf-debug "cape")
+;;;###autoload (autoload 'cape-capf-inside-code "cape")
 ;;;###autoload (autoload 'cape-capf-inside-comment "cape")
 ;;;###autoload (autoload 'cape-capf-inside-faces "cape")
 ;;;###autoload (autoload 'cape-capf-inside-string "cape")
@@ -1176,12 +1191,12 @@ This function can be used as an advice around an existing Capf."
 
 (dolist (wrapper (list #'cape-wrap-accept-all #'cape-wrap-buster
                        #'cape-wrap-case-fold #'cape-wrap-debug
-                       #'cape-wrap-inside-comment #'cape-wrap-inside-faces
-                       #'cape-wrap-inside-string #'cape-wrap-nonexclusive
-                       #'cape-wrap-noninterruptible #'cape-wrap-passthrough
-                       #'cape-wrap-predicate #'cape-wrap-prefix-length
-                       #'cape-wrap-properties #'cape-wrap-purify
-                       #'cape-wrap-silent #'cape-wrap-super))
+                       #'cape-wrap-inside-code #'cape-wrap-inside-comment
+                       #'cape-wrap-inside-faces #'cape-wrap-inside-string
+                       #'cape-wrap-nonexclusive #'cape-wrap-noninterruptible
+                       #'cape-wrap-passthrough #'cape-wrap-predicate
+                       #'cape-wrap-prefix-length #'cape-wrap-properties
+                       #'cape-wrap-purify #'cape-wrap-silent #'cape-wrap-super))
   (let ((name (string-remove-prefix "cape-wrap-" (symbol-name wrapper))))
     (defalias (intern (format "cape-capf-%s" name))
       (lambda (capf &rest args) (lambda () (apply wrapper capf args)))
